@@ -3,6 +3,25 @@ from .tokens import ChanModes, Prefix
 
 CASEMAPPINGS = ["rfc1459", "ascii"]
 
+def _parse_escapes(s: str):
+    idx   = 0
+    out = ""
+
+    while idx < (len(s)):
+        if s[idx] == "\\":
+            if s[idx+1:]:
+                if (s[idx+1] == "x" and
+                        len(s[idx+2:]) >= 2):
+                    out += chr(int(s[idx+2:idx+4], 16))
+                    idx += 4
+                else:
+                    out += s[idx+1]
+                    idx += 2
+        else:
+            out += s[idx]
+            idx += 1
+    return out
+
 class ISupport(object):
     raw: Dict[str, Optional[str]]
 
@@ -23,6 +42,7 @@ class ISupport(object):
     monitor: Optional[int] = None # -1 if "no limit"
     watch:   Optional[int] = None # -1 if "no limit"
     whox:    bool          = False
+    nicklen: int           = 9 # from RFC1459
 
     def __init__(self):
         self.raw = {}
@@ -30,6 +50,7 @@ class ISupport(object):
     def from_tokens(self, tokens: List[str]):
         for token in tokens:
             key, sep, value = token.partition("=")
+            value = _parse_escapes(value)
             self.raw[key] = value if sep else None
 
             if   key == "NETWORK":
@@ -69,3 +90,6 @@ class ISupport(object):
 
             elif key == "WHOX":
                 self.whox = True
+
+            elif key == "NICKLEN":
+                self.nicklen = int(value)
