@@ -683,9 +683,10 @@ class Server(object):
             away     = "" if "G" in status else None
             realname = line.params[9]
 
-            account: Optional[str] = None
+            account  = ""
             if not line.params[8] == "0":
                 account = line.params[8]
+
             server:  Optional[str] = None
             if not line.params[5] == "*":
                 server  = line.params[5]
@@ -778,6 +779,24 @@ class Server(object):
             user.realname = realname
         return emit
 
+    @line_handler("RENAME")
+    def _handle_RENAME(self, line: Line) -> Emit:
+        source_fold = self.casefold(line.params[0])
+        rename      = line.params[1]
+        rename_fold = self.casefold(rename)
+
+        if source_fold in self.channels:
+            channel = self.channels.pop(source_fold)
+
+            channel.change_name(rename, rename_fold)
+            for nickname in channel.users.keys():
+                user = self.users[nickname]
+                user.channels.remove(source_fold)
+                user.channels.add(rename_fold)
+
+            self.channels[rename_fold] = channel
+        return self._emit()
+
     @line_handler(RPL_AWAY)
     # sent in response to a command directed at a user who is marked as away
     def _handle_RPL_AWAY(self, line: Line) -> Emit:
